from installclass import BaseInstallClass
import rhpl
from rhpl.translate import N_,_
from constants import *
from flags import flags
import os
import iutil
import types
try:
    import instnum
except ImportError:
    instnum = None

import logging
log = logging.getLogger("anaconda")

# custom installs are easy :-)
class InstallClass(BaseInstallClass):
    # name has underscore used for mnemonics, strip if you dont need it
    id = "springdale"
    name = N_("Springdale/PUIAS Linux")
    description = N_("The default installation of %s includes a set of "
                     "software applicable for general internet usage. "
                     "What additional tasks would you like your system "
                     "to include support for?") %(productName,)
    sortPriority = 10000
    allowExtraRepos = True

    taskMap = {'client'        : [(N_("Office"), ["office"]),
                                  (N_("Multimedia"), ["graphics", 
                                                      "sound-and-video"])],
               'server'        : [(N_("Software Development"), 
                                   ["development-libs", "development-tools",
                                    "gnome-software-development", 
                                    "x-software-development"],),
                                  (N_("Web server"), ["web-server"])],
               'workstation'   : [(N_("Software Development"), 
                                   ["development-libs", "development-tools",
                                    "gnome-software-development", 
                                    "x-software-development"],)],
               'vt'            : [(N_("Virtualization"), ["virtualization"])],
               'cluster'       : [(N_("Clustering"), ["clustering"])],
               'clusterstorage': [(N_("Storage Clustering"), 
                                   ["cluster-storage"])]
             }

    def setInstallData(self, anaconda):
	BaseInstallClass.setInstallData(self, anaconda)
        BaseInstallClass.setDefaultPartitioning(self, anaconda.id.partitions,
                                                CLEARPART_TYPE_LINUX)

    def setGroupSelection(self, anaconda):
        grps = anaconda.backend.getDefaultGroups(anaconda)
        map(lambda x: anaconda.backend.selectGroup(x), grps)

    def setSteps(self, dispatch):
	BaseInstallClass.setSteps(self, dispatch);
	dispatch.skipStep("partition")
	dispatch.skipStep("regkey", skip = 0)        

    # for rhel, we're putting the metadata under productpath
    def getPackagePaths(self, uri):
        rc = {}
        for (name, path) in self.repopaths.items():
            if not type(uri) == types.ListType:
                uri = [uri,]
            if not type(path) == types.ListType:
                path = [path,]

            lst = []
            lstupdate = []
            for i in uri:
                if i.startswith("http:") and i.find("/data/PU_IAS/5") != -1:
                    iupdate = i.replace("/data/PU_IAS/5", "/data/PU_IAS/updates/5")
                elif i.startswith("http:") and i.find("/data/puias/5") != -1:
                    iupdate = i.replace("/data/puias/5", "/data/puias/updates/5")
                else:
                    iupdate = None
                for p in path:
                    lst.append("%s/%s" % (i, p))
                    if iupdate:
                        if p.endswith("Addons"):
                            iaddons = iupdate.replace("/en/os/","/en/addons/")
                            paddons = p.replace("Addons","")
                            lstupdate.append("%s/%s" % (iaddons, paddons))
                        else:
                            lstupdate.append("%s/%s" % (iupdate, p))
                        

            rc[name] = lst
            if lstupdate:
                rc[name+"_update"] = lstupdate


        log.info("package paths is %s" %(rc,))
        return rc

    def handleRegKey(self, key, intf, interactive = True):
        # self.repopaths = { "base": "%s" %(productPath,) }
        self.tasks = self.taskMap[productPath.lower()]
        self.installkey = key

        splitkey = key.split(",")
        # the first entry is always the base for us
        self.repopaths["base"] = splitkey[0]
        log.info("Setting base to %s" %(splitkey[0],))
        for s in splitkey[1:]:
            ss = s.strip()
            self.repopaths[ss.lower()] = ss
            log.info("Adding " + ss + " option")
	# if we have ClientAddons and Workstation then add WorkstationAddons too
	if "clientaddons" in self.repopaths:
            self.repopaths["workstationaddons"] = "WorkstationAddons"
            log.info("Adding WorkstationAddons option")

        for repo in self.repopaths.values():
            if not self.taskMap.has_key(repo.lower()):
                continue

            for task in self.taskMap[repo.lower()]:
                if task not in self.tasks:
                    self.tasks.append(task)
        self.tasks.sort()

        log.info("repopaths is %s" %(self.repopaths,))

    def __init__(self, expert):
	BaseInstallClass.__init__(self, expert)

        self.repopaths = { "base": "%s" %(productPath,) }

        # minimally set up tasks in case no key is provided
        self.tasks = self.taskMap[productPath.lower()]

